==> jc-1.4.0.tar.gz: scm/Env.h <==
// class scm.Env

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 7cdfd1539eaf66a scm_Env

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_scm_Env_H_
#define _JC_scm_Env_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Hashtable$object;
struct _jc_scm_Cell$object;
struct _jc_scm_Env$object;
struct _jc_scm_Obj$object;
struct _jc_scm_Symbol$object;

// Typedefs
typedef struct _jc_scm_Env$sub_refs	_jc_scm_Env$sub_refs;
typedef struct _jc_scm_Env$sub_nonrefs	_jc_scm_Env$sub_nonrefs;
typedef struct _jc_scm_Env$refs	_jc_scm_Env$refs;
typedef struct _jc_scm_Env$nonrefs	_jc_scm_Env$nonrefs;
typedef struct _jc_scm_Env$object	_jc_scm_Env$object;

typedef struct _jc_scm_Env$fields_struct	_jc_scm_Env$fields_struct;
typedef const struct _jc_scm_Env$vmethods	_jc_scm_Env$vmethods;
typedef const struct _jc_scm_Env$vtable	_jc_scm_Env$vtable;
typedef const struct _jc_scm_Env$vtype	_jc_scm_Env$vtype;

// Class fields structure
struct _jc_scm_Env$fields_struct {
	struct _jc_java_lang_Object$object	*MAGIC__5fKLUDGE;
};
extern _jc_scm_Env$fields_struct _jc_scm_Env$class_fields;

// Constructors
extern void _jc_scm_Env$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_scm_Env$object *);

// Virtual methods
extern void _jc_scm_Env$method$definevar$63e4bfcb3753e5c7(_jc_env *, struct _jc_scm_Env$object *, struct _jc_scm_Symbol$object *, struct _jc_object *);
extern struct _jc_scm_Env$object *_jc_scm_Env$method$extendenv$2be26416089e6f8c(_jc_env *, struct _jc_scm_Env$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Cell$object *);
extern struct _jc_object *_jc_scm_Env$method$lookup$c9c140484855fd3a(_jc_env *, struct _jc_scm_Env$object *, struct _jc_scm_Symbol$object *);
extern void _jc_scm_Env$method$setvar$333474e36d6d0cce(_jc_env *, struct _jc_scm_Env$object *, struct _jc_scm_Symbol$object *, struct _jc_object *);
extern struct _jc_java_lang_String$object *_jc_scm_Env$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_scm_Env$object *);

// Virtual method descriptors
extern _jc_method _jc_scm_Env$method_info$definevar$63e4bfcb3753e5c7;
extern _jc_method _jc_scm_Env$method_info$extendenv$2be26416089e6f8c;
extern _jc_method _jc_scm_Env$method_info$lookup$c9c140484855fd3a;
extern _jc_method _jc_scm_Env$method_info$setvar$333474e36d6d0cce;
extern _jc_method _jc_scm_Env$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_scm_Env$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_scm_Env$vmethods {
	void	(*definevar$63e4bfcb3753e5c7)(_jc_env *, struct _jc_scm_Env$object *, struct _jc_scm_Symbol$object *, struct _jc_object *);
	struct _jc_scm_Env$object	*(*extendenv$2be26416089e6f8c)(_jc_env *, struct _jc_scm_Env$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Cell$object *);
	struct _jc_object	*(*lookup$c9c140484855fd3a)(_jc_env *, struct _jc_scm_Env$object *, struct _jc_scm_Symbol$object *);
	void	(*setvar$333474e36d6d0cce)(_jc_env *, struct _jc_scm_Env$object *, struct _jc_scm_Symbol$object *, struct _jc_object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_scm_Env$object *);
};

// Vtable
struct _jc_scm_Env$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_scm_Env$vmethods	scm_Env;
};

// Vtype
struct _jc_scm_Env$vtype {
	_jc_type			type;
	_jc_scm_Env$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_Env$sub_refs {
	struct _jc_java_util_Hashtable$object	*bindings;
	struct _jc_scm_Env$object	*parent;
};

// Reference instance fields (object)
struct _jc_scm_Env$refs {
    _jc_scm_Env$sub_refs	scm_Env;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_Env$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_scm_Env$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_scm_Env$sub_nonrefs	scm_Env;
};

// Object instance structure
struct _jc_scm_Env$object {
	_jc_scm_Env$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_Env$vtype	*vtype;
	_jc_scm_Env$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_Env$vtype _jc_scm_Env$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_Env, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_Env$class_object;

#endif	/* _JC_scm_Env_H_ */

==> jc-1.4.6.tar.gz: scm/Env.h <==
// class scm.Env

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 7cdfd1539eaf66a scm_Env

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_scm_Env_H_
#define _JC_scm_Env_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Hashtable$object;
struct _jc_scm_Cell$object;
struct _jc_scm_Env$object;
struct _jc_scm_Obj$object;
struct _jc_scm_Symbol$object;

// Typedefs
typedef struct _jc_scm_Env$sub_refs	_jc_scm_Env$sub_refs;
typedef struct _jc_scm_Env$sub_nonrefs	_jc_scm_Env$sub_nonrefs;
typedef struct _jc_scm_Env$refs	_jc_scm_Env$refs;
typedef struct _jc_scm_Env$nonrefs	_jc_scm_Env$nonrefs;
typedef struct _jc_scm_Env$object	_jc_scm_Env$object;

typedef struct _jc_scm_Env$fields_struct	_jc_scm_Env$fields_struct;
typedef const struct _jc_scm_Env$vmethods	_jc_scm_Env$vmethods;
typedef const struct _jc_scm_Env$vtable	_jc_scm_Env$vtable;
typedef const struct _jc_scm_Env$vtype	_jc_scm_Env$vtype;

// Class fields structure
struct _jc_scm_Env$fields_struct {
	struct _jc_java_lang_Object$object	*MAGIC__5fKLUDGE;
};
extern _jc_scm_Env$fields_struct _jc_scm_Env$class_fields;

// Constructors
extern void _jc_scm_Env$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_scm_Env$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_scm_Env$method$definevar$63e4bfcb3753e5c7(_jc_env *, struct _jc_scm_Env$object *, struct _jc_scm_Symbol$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_scm_Env$object *_jc_scm_Env$method$extendenv$2be26416089e6f8c(_jc_env *, struct _jc_scm_Env$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Cell$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_scm_Env$method$lookup$c9c140484855fd3a(_jc_env *, struct _jc_scm_Env$object *, struct _jc_scm_Symbol$object *) _JC_JCNI_ATTR;
extern void _jc_scm_Env$method$setvar$333474e36d6d0cce(_jc_env *, struct _jc_scm_Env$object *, struct _jc_scm_Symbol$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_scm_Env$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_scm_Env$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_scm_Env$method_info$definevar$63e4bfcb3753e5c7;
extern _jc_method _jc_scm_Env$method_info$extendenv$2be26416089e6f8c;
extern _jc_method _jc_scm_Env$method_info$lookup$c9c140484855fd3a;
extern _jc_method _jc_scm_Env$method_info$setvar$333474e36d6d0cce;
extern _jc_method _jc_scm_Env$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_scm_Env$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_scm_Env$vmethods {
	void	(*definevar$63e4bfcb3753e5c7)(_jc_env *, struct _jc_scm_Env$object *, struct _jc_scm_Symbol$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_scm_Env$object	*(*extendenv$2be26416089e6f8c)(_jc_env *, struct _jc_scm_Env$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Cell$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*lookup$c9c140484855fd3a)(_jc_env *, struct _jc_scm_Env$object *, struct _jc_scm_Symbol$object *) _JC_JCNI_ATTR;
	void	(*setvar$333474e36d6d0cce)(_jc_env *, struct _jc_scm_Env$object *, struct _jc_scm_Symbol$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_scm_Env$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_scm_Env$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_scm_Env$vmethods	scm_Env;
};

// Vtype
struct _jc_scm_Env$vtype {
	_jc_type			type;
	_jc_scm_Env$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_Env$sub_refs {
	struct _jc_java_util_Hashtable$object	*bindings;
	struct _jc_scm_Env$object	*parent;
};

// Reference instance fields (object)
struct _jc_scm_Env$refs {
    _jc_scm_Env$sub_refs	scm_Env;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_Env$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_scm_Env$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_scm_Env$sub_nonrefs	scm_Env;
};

// Object instance structure
struct _jc_scm_Env$object {
	_jc_scm_Env$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_Env$vtype	*vtype;
	_jc_scm_Env$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_Env$vtype _jc_scm_Env$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_Env, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_Env$class_object;

#endif	/* _JC_scm_Env_H_ */
